TriplesNumericLiteralsFactory
=============================

.. currentmodule:: pykeen.triples

.. autoclass:: TriplesNumericLiteralsFactory
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TriplesNumericLiteralsFactory.file_name_literal_to_id
      ~TriplesNumericLiteralsFactory.file_name_numeric_literals
      ~TriplesNumericLiteralsFactory.literal_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~TriplesNumericLiteralsFactory.clone_and_exchange_triples
      ~TriplesNumericLiteralsFactory.from_labeled_triples
      ~TriplesNumericLiteralsFactory.from_path
      ~TriplesNumericLiteralsFactory.get_numeric_literals_tensor
      ~TriplesNumericLiteralsFactory.iter_extra_repr
      ~TriplesNumericLiteralsFactory.to_path_binary

   .. rubric:: Attributes Documentation

   .. autoattribute:: file_name_literal_to_id
   .. autoattribute:: file_name_numeric_literals
   .. autoattribute:: literal_shape

   .. rubric:: Methods Documentation

   .. automethod:: clone_and_exchange_triples
   .. automethod:: from_labeled_triples
   .. automethod:: from_path
   .. automethod:: get_numeric_literals_tensor
   .. automethod:: iter_extra_repr
   .. automethod:: to_path_binary
